const symbolPlay = '⯈';
const symbolPause = '❚ ❚';
const files = ['Nature-8399','River-655','Waterfall-941','Wave-2737'];

document.addEventListener("DOMContentLoaded", function() {
   // setup references to elements
   const video = document.querySelector('#vidPlayer');
   const playBtn = document.querySelector('#play');
   const stopBtn = document.querySelector('#stop');
   const progressBar = document.querySelector('#progressFilled');
   const vol = document.querySelector('#volume'); 
   const skipBtns = document.querySelectorAll('[data-skip]');  
   // add images to the video list   
   createVideoList(files);
   // set up event handlers for our buttons and video 
   for (let btn of skipBtns) {
      btn.addEventListener('click', skip);
   }
   stopBtn.addEventListener('click', stopPlaying);
   playBtn.addEventListener('click', playOrPause);
   video.addEventListener('click', playOrPause);
   video.addEventListener('play', updateButton);
   video.addEventListener('pause', updateButton);
   video.addEventListener('timeupdate', handleProgress);    
   vol.addEventListener('input', changeVolume);

   /* ------------ helper functions ------------------- */

   // create the visual list of possible videos to play
   function createVideoList(files) {
      const aside = document.querySelector('aside');
      for (let f of files) {
         const img = document.createElement('img');
         img.src = `images/${f}.jpg`;
         //img.dataset.name = f;
         aside.appendChild(img);
   
         img.addEventListener('click', function(e) {
            stopPlaying(); 
            video.src = `videos/${f}.mp4`;
                    
         })
      }
   }

   // either play or pause the video
   function playOrPause() {
      if (video.paused) {
         video.play();
      } else {
         video.pause();
      }
   }

   // skip video forward/backwards
   function skip (e) {
      video.currentTime += parseInt(e.target.dataset.skip);
   }

   // stop the video from playing
   function stopPlaying() {
      video.pause();
      video.currentTime = 0;
      handleProgress();
      updateButton();
   }

   // update visual state of the play/pause button
   function updateButton() {
      const icon = video.paused ? symbolPlay : symbolPause;
      playBtn.textContent = icon;
   }

   // update the progress bar
   function handleProgress() {
      const percent = (video.currentTime / video.duration) * 100;
      progressBar.style.flexBasis = `${percent}%`;
   }

   // change the volume of video playback
   function changeVolume() {
      video.volume = vol.value;
   }

});
