import { Play  }  from "./play-module.js";

document.addEventListener("DOMContentLoaded", function() {

   document.querySelector("#interface").style.display = "none";
   document.querySelector("#playList").addEventListener('change', () => {
      if (document.querySelector("#playList").value != 0) {
         loadPlayData( document.querySelector("#playList").value );
      }
   });


   async function loadPlayData(filename) {
      const url = 'https://www.randyconnolly.com/funwebdev/3rd/api/shakespeare/play.php';
      const response = await fetch(url + '?name=' + filename);
      const data = await response.json();

      // now create Play object
      const play = new Play(data);

      // set up user interface based on this play data
      setupInterface(play);
   }

   function setupInterface(play) {
      const playContainer = document.querySelector("section#playHere h2");
      const actContainer = document.querySelector("article#actHere h3");
      const sceneContainer = document.querySelector("div#sceneHere");

      // reset interface
      document.querySelector("#interface").style.display = "block";
      playContainer.textContent = "";
      actContainer.textContent = "";
      sceneContainer.textContent = "";

      // first populate select lists 
      let currentAct = play.acts[0];
      let currentScene = play.acts[0].scenes[0];

      populatePlayerSelect(play.players);
      populateActSelect(play.acts);
      populateSceneSelect(currentAct);

      // then output play, act, and scene data
      play.output(playContainer, actContainer, sceneContainer);

      // when new act is selected, update scene list and scene data
      document.querySelector("#actList").addEventListener('change', () => { 
         var index = document.querySelector("#actList").selectedIndex;
         if (index < 0) index = 0;
         currentAct = play.acts[ index ];
         populateSceneSelect(currentAct);     
         resetFilters(); 
         currentAct.output(actContainer, sceneContainer);
      });

      // when new scene is selected, update scene data
      document.querySelector("#sceneList").addEventListener('change', () => { 
         var index = document.querySelector("#sceneList").selectedIndex;
         if (index < 0) index = 0;
         currentScene = currentAct.scenes[ index ];
         resetFilters();
         currentScene.output(sceneContainer);
      });   


      // when 
      document.querySelector("#btnHighlight").addEventListener('click', () => {
         const search = document.querySelector("#txtHighlight").value;
         const player = document.querySelector("#playerList").value;


         sceneContainer.innerHTML = "";
         const scene = currentAct.scenes.find( s => s.name == document.querySelector("#sceneList").value);
         if (scene)
            scene.output(sceneContainer, search, player);
         else {
            scenes.forEach( s => {
               s.output(sceneContainer, search, player);
            })         
         }

      });
   }


});


function resetFilters() {
   document.querySelector("#txtHighlight").value = "";
   document.querySelector("#playerList").value = 0;

}
function populatePlayerSelect(players) {
   document.querySelector("#playerList").innerHTML = "";
   players.forEach(p => {
      const opt = document.createElement('option');
      opt.textContent = p.player;
      document.querySelector("#playerList").appendChild(opt);      
   });   
}
function populateActSelect(acts) {
   document.querySelector("#actList").innerHTML = "";
   acts.forEach(a => {
      const opt = document.createElement('option');
      opt.textContent = a.name;
      document.querySelector("#actList").appendChild(opt);
   });
}
function populateSceneSelect(act) {
   document.querySelector("#sceneList").innerHTML = "";
   act.scenes.forEach(s => {
      const opt = document.createElement('option');
      opt.textContent = s.name;
      document.querySelector("#sceneList").appendChild(opt);
   });
}