import { CompanyCollection } from "./CompanyCollection.js";

/* note: you may get both a CORS error and module error if you test this locally 
   (i.e., directly from a local file). To work correctly, this needs to be tested on a 
   local web server. Some possibilities: if using Visual Code, use Live Server extension; 
   if Brackets, use built-in Live Preview.

   As well, the done version requires you to provide a valid Google Map API in the HTML file.
*/

window.addEventListener('load', function() {

   loadAndDisplayCompanies();



});


async function loadAndDisplayCompanies() {

   const list = document.querySelector('#companiesList');
   const filter = document.querySelector('#txtFilter');
   const clear = document.querySelector('#btnClear');

   const companies = new CompanyCollection();

   const data = await companies.load(list);

   list.addEventListener('click', (e) => {
      if (e.target && e.target.nodeName == 'LI') {
         const symbol = e.target.dataset.id;

         const company = companies.findBySymbol(symbol);         

         // now display description
         document.querySelector('#coName').textContent = `${company.name} (${company.symbol})`;
         document.querySelector('#coSector').textContent = `${company.sector}, ${company.subindustry}`;
         setLinkFromCompany(company.website);
         document.querySelector('#coDesc').textContent = company.description;
         

         // display map
         displayMap( company );

         // display bar charts

         const financials = company.financials ;
         if (financials) {
            displayChart(financials.years, financials.revenue, "Revenue", financials.earnings, "Earnings", "incomeChartDiv");
            displayChart(financials.years, financials.assets, "Assets", financials.liabilities, "Liabilities", "balanceChartDiv");
         } else {
            document.querySelector('#incomeChartDiv').innerHTML = "";
            document.querySelector('#balanceChartDiv').innerHTML = "";
         }
        
      }
   });

   filter.addEventListener('change', () => {
      companies.filterTheList(filter.value, list);

   });

   clear.addEventListener('click', () => {
      companies.resetList(list);
      filter.value = "";
   });   

}


function setLinkFromCompany(website) {
   document.querySelector('#coSite a').href = website;
   document.querySelector('#coSite a').textContent = website;

}




function displayMap(company) {
    let map = new google.maps.Map(document.getElementById('map'), {
      center: {lat: company.latitude, lng: company.longitude},

      zoom: 15
    });
    const markerName = `${company.name} (${company.address})`;
    createMarker( map, company.latitude, company.longitude, markerName );
}

function createMarker(map, latitude, longitude, city) {

   let imageLatLong = {lat:  latitude, lng: longitude };

   let marker = new google.maps.Marker({
       position: imageLatLong,
       title: city,
       map: map
   });      
}


function displayChart( xaxis, series1, label1, series2, label2, divName ) {
   
   const trace1 = {
      x: xaxis,
      y: series1,
      name: label1,
      type: 'bar',
      marker: {
         color: '#5C6BC0'
       }      
   };
   const trace2 = {
      x: xaxis,
      y: series2,
      name: label2,
      type: 'bar',
      marker: {
         color: '#FF246D'
       }         
   };      

   const layout = {
      barmode: 'group',
      autosize: false,
      height: 280,
      margin: {
         l: 50,
         r: 10,
         b: 30,
         t: 10,
         pad: 5
       },      
   };
   
   const data = [trace1, trace2];
   const options = {responsive: true, displayModeBar: false, staticPlot: true};
   Plotly.newPlot(divName, data, layout, options);
         
}