import React from 'react';
import './App.css';
import HeaderApp from './components/HeaderApp.js';
import PhotoBrowser from './components/PhotoBrowser.js';
import FavoriteBar from './components/FavoriteBar.js';
import * as cloneDeep from 'lodash/cloneDeep';
import Home from './components/Home.js';
import { Route } from 'react-router-dom';

class App extends React.Component { 
  constructor(props) {
    super(props);
    this.state = { photos: [], favorites: [] };
  }

  async componentDidMount() {
    try {
      const url = "https://randyconnolly.com/funwebdev/3rd/api/travel/images.php?iso=gb";
      const response = await fetch(url);
      const jsonData = await response.json();
      this.setState( {photos: jsonData } );
    }
    catch (error) {
       console.error(error);
    }
  }

  updatePhoto = (id, photo) => {
    // Create deep clone of photo array from state.
    // We will use a lodash function for that task.
    const copyPhotos = cloneDeep(this.state.photos);
    // find photo to update in cloned array
    const photoToReplace = copyPhotos.find( p => p.id === id);
    // replace photo fields with edited values
    photoToReplace.title = photo.title;
    photoToReplace.location.city = photo.location.city;
    photoToReplace.location.country = photo.location.country;
    // update state
    this.setState( {photos: copyPhotos } );
 }


 addPhotoToFavorites = (photo) => {
    // create clone of favorites array from state
    const copyFavs = cloneDeep(this.state.favorites);

    // create favorite
    //const favToAdd = { photo };

    // if photo already exists in favorites then exit/ignore
    let found = copyFavs.find( p => p.id === photo.id);
    if (found) return;

    // add fav to clone
    copyFavs.push(photo);

    // update state
    this.setState( {favorites: copyFavs } );
  }   


  removePhotoFromFavorites = (photo) => {  
    // remove fav from clone
    let filteredFavs = this.state.favorites.filter( p => p.id !== photo.id);

    // update state
    this.setState( {favorites: filteredFavs } );

  }
 
  
  render() {
    return (
      <main>
        <HeaderApp />
        <Route path='/' exact component={Home} />
        <Route path='/home' exact component={Home} />
        <Route path='/browse' exact 
          render={ (props) => 
            <section>
              <FavoriteBar data={this.state.favorites} 
                    removePhotoFromFavorites={this.removePhotoFromFavorites} />
              <PhotoBrowser 
                 photos={this.state.photos}
                 updatePhoto={this.updatePhoto} 
                 addPhotoToFavorites={this.addPhotoToFavorites}  /> 
            </section>
                 } 
         />

      </main>
    );
  }
}

export default App;
