
import './App.css';
import React, { useEffect, useState } from 'react';
import { Layout } from 'antd';
import { Route } from 'react-router-dom';

import LeftSideMenu from "./components/LeftSideMenu.js";
import HomeView from "./components/HomeView.js";
import ClientView from "./components/ClientView.js";
import CompanyView from "./components/CompanyView.js";


const App = () => {

  const [isLoading, setIsLoading] = useState(true);
  const [clients, setClients] = useState([]);
  const [companies, setCompanies] = useState([]);
  const [currentClient, setCurrentClient] = useState(0);
  const [currentCompany, setCurrentCompany] = useState('AMZN');

  useEffect( () => {

    // first see if in localStorage
    const clientsInBrowser = localStorage.getItem('clientsFromAPI');
    // if in localstorage, just use it
    if (clientsInBrowser) {
      setClients(JSON.parse(clientsInBrowser));
    } else {
      const url1 = "https://www.randyconnolly.com/funwebdev/3rd/api/stocks/client.php";
      fetch(url1)
        .then( resp => resp.json() )
        .then( data => {
          setClients(data);
          // put in local storage
          localStorage.setItem('clientsFromAPI', JSON.stringify(data) );          
          setIsLoading(false);
        })
        .catch( err => console.error(err));
    }

/*       const url2 = "https://www.randyconnolly.com/funwebdev/3rd/api/stocks/companies.php";
      fetch(url2)
        .then( resp => resp.json() )
        .then( data => setCompanies(data))
        .catch( err => console.error(err));    */   


  }, []);

  const updateClient = (id) => {
    //const c = clients.find( c => c.id == id);
    setCurrentClient(id);
  };
  const updateCompany = (symbol) => {
    //const c = companies.find( c => c.symbol == symbol);
    setCurrentCompany(symbol);
  };  

  return (
    <Layout>
      <LeftSideMenu />

      <Route path='/' exact >
        <HomeView clients={clients} updateClient={updateClient} loading={isLoading} />
      </Route>
      <Route path='/home' exact >
        <HomeView clients={clients} updateClient={updateClient} loading={isLoading} />
      </Route>
      <Route path='/client' exact >
        <ClientView clients={clients} current={currentClient} updateCompany={updateCompany} />
      </Route>
      <Route path='/company' exact >
        <CompanyView companies={companies} current={currentCompany} />
      </Route>

    </Layout>
  );
}

export default App;

/*
      <Route path='/home' exact 
             render={ (props) => <HomeView clients={clients} updateClient={updateClient} /> } />
      <Route path='/client' exact 
             render={ (props) => <ClientView clients={clients} current={currentClient} updateCompany={updateCompany} /> } />
      <Route path='/company' exact 
             render={ (props) => <CompanyView companies={companies} current={currentCompany} /> } />

*/