
import React, { useEffect, useState } from 'react';
import { Layout, Typography } from 'antd';
import { blue } from '@ant-design/colors';
import { Row, Col, Card } from 'antd';
import './ClientView.css';
import ClientDetails from "./ClientDetails.js";
import PortfolioSummary from "./PortfolioSummary.js";
import PortfolioDetails from "./PortfolioDetails.js";
import TopStocks from "./TopStocks.js";

const { Header, Content } = Layout;
const { Title } = Typography;

const ClientView = props => {

  const client = props.clients.find( c => c.id === props.current);
  const [portfolio, setPortfolio] = useState([]);
  const [isLoading, setIsLoading] = useState(true);

  useEffect( () => {
    const url = "https://www.randyconnolly.com/funwebdev/3rd/api/stocks/portfolio.php?id=" + client.id;
    fetch(url)
      .then( resp => resp.json() )
      .then( data => {
        setPortfolio(data);
        setIsLoading(false);
      })
      .catch( err => console.error(err));

  });

  if (client) {

    return (
      <Layout>

          <Header style={{backgroundColor: blue[4]}}>
            <Title level={3}>{client.firstname + ' ' + client.lastname}</Title>
          </Header>
          <Content style={{backgroundColor: blue[0]}} className="card_container">
            <Row gutter={[16]}>
              <Col span={6}>
                <ClientDetails client={client} />
                <PortfolioSummary client={client} portfolio={portfolio} />
              </Col>
              <Col span={18}>
                <TopStocks portfolio={portfolio} />
                <PortfolioDetails client={client} portfolio={portfolio} />
              </Col>
            </Row>            
          </Content>

      </Layout>
    );
    } else
     return null;


}

export default ClientView;
