<?php
class DatabaseHelper {

    /*  This function returns a connection object to a database   */
    public static function createConnection( $values=array() ) {
        $connString = $values[0];
        $user = $values[1];
        $password = $values[2];
        $pdo = new PDO($connString,$user,$password);
        $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        $pdo->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);
        return $pdo;
    }

    /*
    This function runs the specified SQL query using the 
    passed connection and the passed array of parameters (null if none)
    */
    public static function runQuery($connection, $sql, $parameters=array())     {
        // Ensure parameters are in an array
        if (!is_array($parameters)) {
            $parameters = array($parameters);
        }

        $statement = null;
        if (count($parameters) > 0) {
            // Use a prepared statement if parameters 
            $statement = $connection->prepare($sql);
            $executedOk = $statement->execute($parameters);
            if (! $executedOk) throw new PDOException;
        } else {
            // Execute a normal query     
            $statement = $connection->query($sql); 
            if (!$statement) throw new PDOException;
        }
        return $statement;
    }   
}


class UserDB {
    private static $baseSQL = "SELECT email,firstname,lastname,city,country,password,salt,password_sha256 FROM users ";

    public function __construct($connection) {
        $this->pdo = $connection;
    }

    public function getByEmail($email) {
        $sql = self::$baseSQL . ' WHERE email=?';
        $statement = DatabaseHelper::runQuery($this->pdo, $sql, Array($email));
        return $statement->fetch();
    }   
    
    public function insert($email,$first,$last,$city,$country,$pass,$salt,$shaPass) {
        $sql = "INSERT INTO users VALUES (:email,:first,:last,:city,:country,:pass,:salt,:sha)";
        $statement = DatabaseHelper::runQuery($this->pdo, $sql, Array("email"=>$email,"first"=>$first,"last"=>$last,"city"=>$city,"country"=>$country,"pass"=>$pass,"salt"=>$salt,"sha"=>$shaPass) );
    }
}


?>